#!/usr/bin/php
<?php

function logger($facility, $msg)
{
  openlog("CustomerServer", LOG_PID | LOG_NDELAY, LOG_LOCAL0);
  syslog($facility, $msg);  
}

# We must use 'cert_serial' instead of 'common_name', because
# otherwise there is confusion about devices' identity after
# CS is reinstalled with import of previous certificates. 
$cert_serial = getenv('tls_serial_0');
$real_ip     = getenv('trusted_ip');

$phpclientapi = new CSPhpClientApi();

try {
  $device = $phpclientapi->get_device_by_cert_serial($cert_serial);
  
  if ($device['validated'] == "0") {
    throw new Exception('Standa is not validated.');
  }
  if ($device['disabled'] == "1") {
    throw new Exception('Standa is disabled.');
  }
  if ($device['device_type'] != "1") { # 1 = RW, 2 = Router
    throw new Exception('Wrong device type [' . $device['device_type'] . '].');
  }
  $phpclientapi->set_rw_online($device['device_id'], $real_ip);
  $phpclientapi->add_connlog_connect($device['device_id']);
} catch (Exception $exception) {
  logger(LOG_DEBUG, "DENIED OpenVPN access to Standalone client ($real_ip): " . $exception->getMessage());
  exit(1);
}
