<?php

namespace AppBundle\Api;

use Monolog\Logger;

/**
 * Class StandaloneVpnClient
 * @package AppBundle\Api
 */
class StandaloneVpnClient{

    /**
     * @var \PhpClientApi
     */
    protected $phpClientApi;

    /**
     * @var Logger
     */
    protected $log;

    /**
     * StandaloneVpnClient constructor.
     * @param $phpClientApi
     * @param Logger $log
     */
    function __construct($phpClientApi, Logger $log) {

        $this->phpClientApi = $phpClientApi;
        $this->log = $log;

    }

    /**
     * @param $start
     * @param $length
     * @param array $order
     * @param array $filter
     * @return array
     */
    public function getStandaloneVpnClients($start, $length, array $order = array(), array $filter = array()) {

        $aOrder = array();

        foreach($order as $col => $order){

            $aOrder[] = array($col, $order);

        }

        try{

            $devList = $this->phpClientApi->get_all_roadwarriors($start, $length, $filter, $aOrder);

        }catch (\Exception $e){

            $this->logError(__FUNCTION__, func_get_args(), $e);

            $devList = array();

        }

        return $devList;

    }

    /**
     * @param null $filter
     * @return mixed
     */
    public function getCountOfAllStandaloneVpnClients($filter = null) {

        if($filter == null){

            $filter = array();

        }

        try{

            return $this->phpClientApi->get_all_standas_count($filter);

        }catch (\Exception $e){

            $this->logError(__FUNCTION__, func_get_args(), $e);

            return 0;

        }

    }

    /**
     * @param $deviceId
     * @return mixed
     */
    public function getStandaloneVpnClientById($deviceId) {

        try{

            return $this->phpClientApi->get_roadwarrior_by_id((int) $deviceId);

        }catch (\Exception $e){

            $this->logError(__FUNCTION__, func_get_args(), $e);

            return array();

        }

    }

    /**
     * @param array $standaloneVpnClinent
     * @return bool|string
     */
    public function addStandaloneVpnClient(array $standaloneVpnClinent){

        try{

            $this->phpClientApi->add_roadwarrior($standaloneVpnClinent);

            return true;

        }catch (\Exception $e){

            $this->logError(__FUNCTION__, func_get_args(), $e);

            return $e->getMessage();

        }

    }

    /**
     * @param $standaloneVpnClienId
     * @return bool
     */
    public function deleteStandaloneVpnClient($standaloneVpnClienId){

        try{

            return $this->phpClientApi->delete_roadwarrior((int) $standaloneVpnClienId);

        }catch (\Exception $e){

            $this->logError(__FUNCTION__, func_get_args(), $e);

            return false;

        }

    }

    /**
     * @param $functionName
     * @param array $arguments
     * @param \Exception|null $exception
     */
    private function logError($functionName, array $arguments, \Exception $exception = null){

        try{

            $ref = new \ReflectionMethod($this, $functionName);
            $functionParameters = [];

            foreach($ref->getParameters() as $key => $currentParameter) {

                $functionParameters[$currentParameter->getName()] = $arguments[$key];

            }

            $this->log->addError('Exception ' . (($exception !== null) ? '"' .$exception->getMessage(). '"' : '').' on '. $functionName .', parameters:' . print_r(serialize($functionParameters), true));

        }catch (\Exception $e){

            $this->log->addError('Exception ' . (($exception !== null) ? '"' .$exception->getMessage(). '"' : '').' on '. $functionName);

        }

    }

}