<?php

namespace AppBundle\Controller\Ajax;

use AppBundle\Entity\User;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Route;
use Sensio\Bundle\FrameworkExtraBundle\Configuration\Method;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\BinaryFileResponse;

/**
 * Class AjaxStandaloneVpnClientsController.
 */
class AjaxStandaloneVpnClientsController extends AjaxBaseController
{
    /**
     * Render Ajax page.
     *
     * @Route("ajax/standalone-vpn-clients", name="app_ajax_standalone_vpn_clients_table")
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxAction(Request $request)
    {
        //If is not ajax
        if (!$request->isXmlHttpRequest()) {
            return new Response('Bad Request', 400);
        }

        list($start, $length, $aOrder, $filter) = $this->parseData($request);

        //workaround for connected column (change request data so filter and order of disabled works)
        $filter = $this->filterDisabled($filter);
        $aOrder = $this->orderDisabled($aOrder);

        $standaloneVpnClients = $this->apiStandaloneVpnClients->getStandaloneVpnClients($start, $length, $aOrder, $filter);

        if (empty($standaloneVpnClients)) {
            $standaloneVpnClients = array();
        }

        //workaround for connected column (online with value 2 used for disabled, after getting from db)
        $standaloneVpnClients = $this->getDisabled($standaloneVpnClients);

        $data = [
            'recordsTotal' => $this->apiStandaloneVpnClients->getCountOfAllStandaloneVpnClients(),
            'recordsFiltered' => $this->apiStandaloneVpnClients->getCountOfAllStandaloneVpnClients($filter),
            'data' => $standaloneVpnClients,
        ];

        return new JsonResponse($data);
    }

    /**
     * Render Ajax page.
     *
     * @Route("ajax/standalone-vpn-client-remove", options={"expose"=true}, name="app_ajax_remove_standalone_vpn_client")
     * @Method({"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxRemoveStandaloneVpnClientAction(Request $request)
    {
        //If is not ajax
        if (!$request->isXmlHttpRequest()) {
            return new Response('Bad Request', 400);
        }

        $this->denyAccessUnlessGranted(User::ROLE_NET_ADMIN);

        $data = json_decode($request->getContent(), true);
        $request->request->replace($data);

        $vpnClientId = $request->request->get('rwId');

        try {
            $this->apiStandaloneVpnClients->deleteStandaloneVpnClient($vpnClientId);

            $data = array('status' => 'success', 'msg' => '');
        } catch (\Exception $e) {
            $data = array('status' => 'failed', 'msg' => '');
        }

        return new JsonResponse($data);
    }

    /**
     * Render Ajax page.
     *
     * @Route("ajax/standalone-vpn-clients-remove", options={"expose"=true}, name="app_ajax_remove_standalone_vpn_clients")
     * @Method({"POST"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxRemoveStandaloneVpnClientsAction(Request $request)
    {
        //If is not ajax
        if (!$request->isXmlHttpRequest()) {
            return new Response('Bad Request', 400);
        }

        $this->denyAccessUnlessGranted(User::ROLE_NET_ADMIN);

        $data = json_decode($request->getContent(), true);
        $request->request->replace($data);

        $ids = $request->request->get('ids');

        try {
            foreach ($ids as $id) {
                $this->apiStandaloneVpnClients->deleteStandaloneVpnClient($id);
            }

            $data = array('status' => 'success', 'msg' => implode(',', $ids));
        } catch (\Exception $e) {
            $data = array('status' => 'failed', 'msg' => implode(',', $ids));
        }

        return new JsonResponse($data);
    }

    /**
     * Render Ajax page.
     *
     * @Route("ajax/standalone-vpn-client-download", options={"expose"=true}, name="app_ajax_download_config_file")
     * @Method({"GET"})
     *
     * @param Request $request
     *
     * @return Response
     */
    public function ajaxDownloadRoadWarriorConfigFileAction(Request $request){

        $this->denyAccessUnlessGranted(User::ROLE_NET_ADMIN);

        $filename = $request->query->get('downloadFile');

        return new BinaryFileResponse($filename);
    }

    /**
     * @param $request
     *
     * @return array
     */
    private function parseData($request)
    {
        $parametersToValidate = $request->query->all();

        $start = $request->query->getInt('start');
        $length = $request->query->getInt('length');

        $columns = array(
            2 => 'name',
            //2 => 'rw_email',
            //3 => 'online',
            3 => 'ovpn_ip',
            4 => 'label',
            5 => 'network_cnt',
            6 => 'expiration_date',
            7 => 'online',
        );

        // Individual column filtering
        $filterColumns = $request->query->get('columns');
        $search = $request->query->get('search');

        $filter = array();

        if (isset($search['value']) && !empty($search['value'])) {
            $filter[$columns[1]] = '%'.$search['value'].'%';
        } else {
            foreach ($filterColumns as $key => $column) {
                $columnIdx = array_search($column['data'], $columns);

                if ($columnIdx && '' != $column['search']['value']) {
                    $filter[$columns[$columnIdx]] = '%'.$column['search']['value'].'%';
                }
            }
        }

        $order = $request->query->get('order');
        $aOrder = array();

        foreach ($order as $item) {
            $aOrder[$columns[$item['column']]] = $item['dir'];
        }

        return array($start, $length, $aOrder, $filter);
    }

    /**
     * @param $devices
     *
     * @return array
     */
    private function getDisabled($devices)
    {
        //get disabled routers as online with value "2" (in column "connected")
        foreach ($devices as &$device) {
            if ('1' == $device['disabled']) {
                $device['online'] = '2';
            }
        }

        return $devices;
    }

    /**
     * @param $filter
     *
     * @return array
     */
    private function filterDisabled($filter)
    {
        //change filter request for nonexisting value 2 in column connected
        if (array_key_exists('online', $filter)) {
            if ('%2%' == $filter['online']) {
                $filter['online'] = '0';
                $filter['disabled'] = '1';
            } else {
                $filter['disabled'] = '0';
            }
        }

        return $filter;
    }

    /**
     * @param $order
     *
     * @return array
     */
    private function orderDisabled($order)
    {
        //change order request for online column so it orders also disabled devices
        if (array_key_exists('online', $order)) {
            if ('asc' == $order['online']) {
                $order['disabled'] = 'asc';
                $order['online'] = 'desc';
            } else {
                $order['disabled'] = 'desc';
                $order['online'] = 'asc';
            }
        }

        return $order;
    }
}
