<?php

namespace AppBundle\Form;

use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\FormType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\Form\Extension\Core\Type\TextType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\OptionsResolver\OptionsResolver;

class Settings extends AbstractType
{

    /**
     * @param FormBuilderInterface $builder
     * @param array $options
     */
    public function buildForm(FormBuilderInterface $builder, array $options){

        $apiCsSettings = $options['apiCsSettings'];

        $sections = $apiCsSettings->getSettingsSectionsInfo(); 

        foreach ($sections as $section){

            $settings = $apiCsSettings->getSettingsBySection($section['section_id']);  
            if (empty($settings)) {
              continue;
            }

            $sectionBuilder = $builder->create($section['name'], FormType::class, array('inherit_data' => true));

            foreach ($settings as $item){

                //var_dump($item);

                switch ($item['name']) {
                    case 'SYSLOG_LOGLEVEL':
                        $builder->add(
                            $sectionBuilder->add($item['name'], ChoiceType::class, array(
                                'label' => $item['label'],
                                'required' => false,
                                'placeholder' => false,
                                'choices'  => [
                                    'Emergency' => '0',
                                    'Alert' => '1',
                                    'Critical' => '2',
                                    'Error' => '3',
                                    'Warning' => '4',
                                    'Notice' => '5',
                                    'Info' => '6',
                                    'Debug' => '7'
                            ]))
                        );
                        break;

                    case 'PROXY_DEFAULT_ENABLED':
                        $builder->add(
                            $sectionBuilder->add($item['name'], ChoiceType::class, array(
                                'label' => $item['label'],
                                'required' => false,
                                'placeholder' => false,
                                'choices'  => [
                                    'Yes' => '1',
                                    'No' => '0'
                                ]))
                        );
                        break;

                    case 'PROXY_DEFAULT_LAN_ENABLED':
                        $builder->add(
                            $sectionBuilder->add($item['name'], ChoiceType::class, array(
                                'label' => $item['label'],
                                'required' => false,
                                'placeholder' => false,
                                'choices'  => [
                                    'Yes' => '1',
                                    'No' => '0'
                            ]))
                        );
                        break;

                    case 'OPENVPN_PROTO':
                         $builder->add(
                             $sectionBuilder->add($item['name'], ChoiceType::class, array(
                                 'label' => $item['label'],
                                 'required' => false,
                                 'placeholder' => false,
                                 'choices'  => [
                                     'TCP' => 'tcp4',
                                     'UDP' => 'udp4'
                                 ]))
                         );
                        break;

                    case 'ROADWARRIOR_PROTO':
                        $builder->add(
                            $sectionBuilder->add($item['name'], ChoiceType::class, array(
                                'label' => $item['label'],
                                'required' => false,
                                'placeholder' => false,
                                'choices'  => [
                                    'TCP' => 'tcp4',
                                    'UDP' => 'udp4'
                                ]))
                        );
                        break;
		    case 'OPENVPN_KEEPALIVE_FREQ':
                    case 'ROADWARRIOR_KEEPALIVE_FREQ':
                        $builder->add(
                            $sectionBuilder->add($item['name'], ChoiceType::class, array(
                                'label' => $item['label'],
                                'required' => false,
                                'placeholder' => false,
                                'choices'  => [
                                    'High'     => '3',
                                    'Medium'   => '2',
                                    'Low'      => '1',
                                    'Very Low' => '0'
                                ]))
                        );
                        break;

                    default:
                        $builder->add(
                            $sectionBuilder->add($item['name'], TextType::class, array('label' => $item['label'], 'required' => false))
                        );
                }


                /*
                if($item['label'] == 'LAN Proxy Enabled'){
                    $builder->add(
                        $sectionBuilder->add($item['name'], ChoiceType::class, array('label' => $item['label'], 'required' => false, 'choices'  => [
                            'Yes' => '1',
                            'No' => '0'
                        ]))
                    );


                } elseif ($item['label'] == 'Level') {

                }
                else {
                    $builder->add(
                        $sectionBuilder->add($item['name'], TextType::class, array('label' => $item['label'], 'required' => false))
                    );
                }
                */
            }
        }

        $builder->add('save', SubmitType::class);

    }

    /**
     * @param OptionsResolver $resolver
     */
    public function configureOptions(OptionsResolver $resolver){

        $resolver->setRequired('apiCsSettings');

    }

}
