/**
 * Show Device detail
 * @param rowData
 * @returns {*|jQuery}
 */
function formatDeviceDetail ( rowData ) {

    var spinner = "<div style=\"padding: 50%; margin: -8px; width: 16px; height: 16px;\"><i class=\"fa fa-spinner fa-spin\"></i><span class=\"h5\" style=\"margin-left: -20px;\">Loading...</span></div>";
    var div = $("<div/>").addClass( "loading" ).html(spinner);
    var url = Routing.generate("app_ajax_device_detail", {"id": "id"});

    if(rowData.hasOwnProperty("id")){
        url = url.replace("id", rowData.id);
    }else{
        url = url.replace("id", rowData.device_id);
    }

    $.ajax( {
        url: url,
        dataType: "json",
        success: function ( json ) {
            div
                .html( json.html )
                .removeClass( "loading" );
        }
    } );

    return div;
}

/**
 * Show Network detail
 * @param rowData
 * @returns {*|jQuery}
 */
function formatNetworkDetail ( rowData ) {

    var spinner = "<div style=\"padding: 50%; margin: -8px; width: 16px; height: 16px;\"><i class=\"fa fa-spinner fa-spin\"></i><span class=\"h5\" style=\"margin-left: -20px;\">Loading...</span></div>";
    var div = $("<div/>").addClass( "loading" ).html(spinner);
    var url = Routing.generate("app_ajax_network_detail", {"id": "id"});

    url = url.replace("id", rowData.network_id);

    $.ajax( {
        url: url,
        dataType: "json",
        success: function ( json ) {
            div
                .html( json.html )
                .removeClass( "loading" );
        }
    } );

    return div;
}

/**
 * Dashboard dataTable
 * @param url
 */
function init_DashboardDeviceDataTable(url) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatable tfoot th').each( function (i) {

        if(i > 1 && i < 5){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }

    } );

    var table = $('#datatable').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 2, "asc" ]],
        "search": {
            "regex": false
        },
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError

        },
        "columns": [
            {
                className:      'select-checkbox',
                orderable:      false,
                data:           null,
                defaultContent: ''
            },
            {
                className:      'details-control text-center',
                orderable:      false,
                data:           null,
                defaultContent: '<i class="fa fa-plus-circle" style="cursor: pointer;" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Show Device Detail"></i>'
            },
            { "data": "name" },
            { "data": 'real_ip'},
            { "data": 'label'},
            {
                data: null,
                "render": function (data, type, full, meta) {

                    if(data['device_id']){
                        id = data['device_id'];
                    }else{
                        id = data['id'];
                    }

                        var deleteUrl = '';

                        if(rights.deviceDelete){

                            deleteUrl = '<a href="#" data-toggle="modal" data-id="'+ id +'" data-target="#removeDeviceModal" data-name="'+data['name']+'" class="editor_remove">Delete</a>';

                        }

                        var validateUrl = '';

                        if(rights.deviceValidate){

                            validateUrl = '<a href="#" onclick="javascript:validateDevice(' + id + ')" class="editor_remove">Validate</a>';  //'<a href="'+validatedUrl+'" class="editor_remove">Validate</a>';

                        }

                        var links = [validateUrl, deleteUrl];

                        return links.filter(function (val) {return val;}).join(' / ');

                }
            }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            {
                'targets': 0,
                'searchable': false,
                'orderable': false,
                'width': '1%',
                'className': 'dt-body-center',
                'render': function (data, type, full, meta){
                    return '<input type="checkbox">';
                }
            },
            {
                "targets": 1,
                'width': '3%',
                "orderable": false
            },
            {
                "targets": 2,
                'width': '20%',
            },
            {
                "targets": 3,
                'width': '20%',
            },
            {
                "targets": 4,
                'width': '40%',
            },
            {
                "targets": 5,
                "orderable": false,
                'searchable': false,
                'width': '20%',
            },
        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
            var api = this.api();

            // Apply the search
            api.columns().every(function(index) {
                var that = this;

                var colIndex = index;


                    if(colIndex !== 5){

                        $('input', this.footer()).on('keyup change', function() {
                            if (that.search() !== this.value) {
                                that
                                    .search(this.value)
                                    .draw();
                            }
                        });

                    }

            });
        }

    } );

    $(".table-striped").find('tr[data-target]').on('click', function(){
        //or do your operations here instead of on show of modal to populate values to modal.
        $('#orderModal').data('id',$(this).data('id'));
    });


    // Handle click on checkbox
    $('#datatable tbody').on('click', 'input[type="checkbox"]', function(e){
        var $row = $(this).closest('tr');

        // Get row data
        var data = table.row($row).data();

        // Get row ID
        var rowId = data['device_id'];

        // Determine whether row ID is in the list of selected row IDs
        var index = $.inArray(rowId, rows_selected);

        // If checkbox is checked and row ID is not in list of selected row IDs
        if(this.checked && index === -1){
            rows_selected.push(rowId);

            // Otherwise, if checkbox is not checked and row ID is in list of selected row IDs
        } else if (!this.checked && index !== -1){
            rows_selected.splice(index, 1);
        }

        if(this.checked){
            $row.addClass('selected');
        } else {
            $row.removeClass('selected');
        }

        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle click on table cells with checkboxes
    // $('#datatable').on('click', 'tbody td, thead th:first-child', function(e){
    //     $(this).parent().find('input[type="checkbox"]').trigger('click');
    // });

    // Handle click on "Select all" control
    $('thead input[name="select_all"]', table.table().container()).on('click', function(e){
        if(this.checked){
            $('#datatable tbody input[type="checkbox"]:not(:checked)').trigger('click');
        } else {
            $('#datatable tbody input[type="checkbox"]:checked').trigger('click');
        }

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle table draw event
    table.on('draw', function(){
        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);
    });

    // Handle form submission event
    $('#frm-example').on('submit', function(e){
        var form = this;

        // Iterate over all selected checkboxes
        $.each(rows_selected, function(index, rowId){
            // Create a hidden element
            $(form).append(
                $('<input>')
                    .attr('type', 'hidden')
                    .attr('name', 'id[]')
                    .val(rowId)
            );
        });
    });


    //
    // Updates "Select all" control in a data table
    //
    function updateDataTableSelectAllCtrl(table){

        var $table             = table.table().node();
        var $chkbox_all        = $('tbody input[type="checkbox"]', $table);
        var $chkbox_checked    = $('tbody input[type="checkbox"]:checked', $table);
        var chkbox_select_all  = $('thead input[name="select_all"]', $table).get(0);

        // If none of the checkboxes are checked
        if($chkbox_checked.length === 0){
            chkbox_select_all.checked = false;
            $('#delete-button').attr('disabled', 'disabled');
            $('#validate-button').attr('disabled', 'disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If all of the checkboxes are checked
        } else if ($chkbox_checked.length === $chkbox_all.length){
            chkbox_select_all.checked = true;
            if(rights.deviceDelete){

                $('#delete-button').removeAttr('disabled');

            }

            if(rights.deviceValidate){

                $('#validate-button').removeAttr('disabled');

            }

            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If some of the checkboxes are checked
        } else {
            chkbox_select_all.checked = true;
            if(rights.deviceDelete){

                $('#delete-button').removeAttr('disabled');

            }

            if(rights.deviceValidate){

                $('#validate-button').removeAttr('disabled');

            }

            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = true;
            }
        }
    }

    $('#datatable tbody').on('click', 'td.details-control', function (e) {

        var table = $('#datatable').DataTable();
        var tr = $(this).closest('tr');
        //console.log(tr);
        var row = table.row( tr );
        //console.log(row);

        var slider = $('#slider');
        slider.html(formatDeviceDetail(row.data()));
        slider.slideReveal({
            position: "right",
            width: 350,
            push: false,
            overlay: true
        });
        slider.css('height','100%');
        slider.css('overflow-y','scroll');
        slider.slideReveal("show");

        e.stopPropagation();

    } );

};

//Device DataTable
function init_RouterDataTable(url, typeOfView = null) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatable tfoot th').each( function (i) {

        if(i > 1 && i != 6 && i != 8){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }

    } );

    var table = $('#datatable').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 2, "asc" ]],
        "search": {
            "regex": false
        },
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError

        },
        "columns": [
            {
                className:      'select-checkbox',
                orderable:      false,
                data:           null,
                defaultContent: ''
            },
            {
                className:      'details-control text-center',
                orderable:      false,
                data:           null,
                defaultContent: '<i class="fa fa-plus-circle" style="cursor: pointer;" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Show Device Detail"></i>'
            },
            { "data": "name"

                /*
                // funguje dela link na nazev device, ale znefunkcni search - nutno spravit
                data: null,
                'render': function (data, type, full, meta){

                    if(data['device_id']){
                        id = data['device_id'];
                    }else{
                        id = data['id'];
                    }
                    var editUrl = '';
                    if(rights.deviceEdit){
                        editUrl = Routing.generate('app_edit_device', {'id': id });
                    }
                    return '<a href="' + editUrl + '" class="editor_edit">' + data['name'] + '</a>';
                }

                 */
            },
            { "data": 'ovpn_ip'},
            { "data": 'label'},
            { "data": "network_cnt" },
            { "data": "online"},
            { "data": "sync_status" },
            {
                data: null,
                "render": function (data, type, full, meta) {

                    if(data['device_id']){
                        id = data['device_id'];
                    }else{
                        id = data['id'];
                    }

                    var editUrl = '';

                    if(rights.deviceEdit){

                        //editUrl = Routing.generate('app_edit_device', {'id': id });
                        //editUrl = '<a href="' + editUrl + '" class="editor_edit" onclick="saveEditReturn()">Edit</a>';

                        //editUrl = Routing.generate('app_edit_device', {'id': id });
                        editUrl = '<a href="#" class="editor_edit" data-id="' + id + '" onclick="saveEditReturn()">Edit</a>';

                    }

                    if(typeOfView == null){

                        var manageDeviceUrl = '';
                        var deleteUrl = '';

                        if(data['proxy_url'] != null && data['proxy_url'] != ''){

                            manageDeviceUrl = '<a href="https://'+data['proxy_url']+'" target="_blank" class="editor_edit">Link</a>';

                        }

                        if(rights.deviceDelete){

                            deleteUrl = '<a href="#" data-toggle="modal" data-id="'+ id +'" data-target="#removeDeviceModal" data-name="'+data['name']+'" class="editor_remove">Delete</a>';

                        }

                        if(data['validated'] == false){

                            var validateUrl = '';

                            if(rights.deviceValidate){

                                validateUrl = '<a href="#" onclick="javascript:validateDevice(' + id + ')" class="editor_remove">Validate</a>';  //'<a href="'+validatedUrl+'" class="editor_remove">Validate</a>';

                            }

                            return validateUrl;

                        }else{

                            var links = [editUrl, manageDeviceUrl, deleteUrl];

                            return links.filter(function (val) {return val;}).join(' / ');
                        }

                    }else{

                        var leaveNetworkUrl = '';

                        if(rights.deviceNetworkLeave){

                            leaveNetworkUrl =  '<a href="#" data-toggle="modal" data-id="'+ id +'" data-target="#leaveNetworkModal" data-name="'+data['name']+'" data-id="'+ id +'" class="editor_remove">Leave</a>';

                        }

                        var links = [editUrl, leaveNetworkUrl];

                        return links.filter(function (val) {return val;}).join(' / ');

                    }
                }
            }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            {
                'targets': 0,
                'searchable': false,
                'orderable': false,
                'width': '1%',
                'className': 'dt-body-center',
                'render': function (data, type, full, meta){
                    return '<input type="checkbox">';
                }
            },
            {
                "targets": 1,
                'width': '3%',
                "orderable": false
            },
            {
                "targets": 2,
                'width': '20%',
            },
            {
                "targets": 3,
                'width': '10%',
            },
            {
                "targets": 5,
                'className': 'dt-center',
                'width': '5%',
            },
            {
                'targets': 6,
                'className': 'dt-center',
                'width': '7%',
                'render': function (data, type, full, meta){
                    if(data == 0){
                        return '<i class="fa fa-stop" style="color: #bb4a1e" aria-hidden="true"></i> Offline';
                    }else if(data == 1){
                        return '<i class="fa fa-exchange" style="color: #1ABB9C" aria-hidden="true"></i> Online';
                    }else if(data == 2){
                        return '<i class="fa fa-stop" style="color: #d3d6da" aria-hidden="true"></i> Disabled';
                    }

                    return 'none';
                }
            },
            {
                'targets': 7,
                //'className': 'dt-center',
                'width': '7%',
                'render': function (data, type, full, meta){
                    if(data == 0){
                        //return '<i class="fa fa-circle " style="color: green" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="OK"></i>';
                        return '<i class="fa fa-circle " style="color: green;padding-left:12%" aria-hidden="true"></i> Synced';
                    }else if(data == 1){
                        //return '<i class="fa fa-circle" style="color: #f9c26f" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Pending"></i>';
                        return '<i class="fa fa-circle" style="color: #f9c26f;padding-left:12%" aria-hidden="true"></i> Pending';
                    }else if(data == 2){
                        //return '<i class="fa fa-circle" style="color: #bb4a1e" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Failed"></i>';
                        return '<i class="fa fa-circle" style="color: #bb4a1e;padding-left:12%" aria-hidden="true"></i> Failed';
                    }

                    return 'none';
                }
            },
            {
                "targets": 8,
                'className': 'actions',
                "orderable": false,
                'searchable': false,
                'width': '10%',
            },
        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
            var api = this.api();

            // Apply the search
            api.columns().every(function(index) {
                var that = this;

                var colIndex = index;

                if (colIndex === 6 || colIndex === 7){

                    var column = this;
                    var select = $('<select><option value=""></option></select>')
                        .appendTo( $(column.footer()).empty() )
                        .on( 'change', function () {
                            var val = $.fn.dataTable.util.escapeRegex(
                                $(this).val()
                            );

                            column
                            //.search( val ? '^'+val+'$' : '', true, false )
                                .search( $(this).val() )
                                .draw();
                        } );

                    column.data().unique().sort().each( function ( d, j) {

                        if(colIndex == 6){

                            if (d === '0'){
                                var val = 'Offline';
                            }else if(d === '1'){
                                var val = 'Online';
                            }else if(d === '2'){
                                var val = 'Disabled';
                            }
                        }

                        if(colIndex == 7){

                            if (d === '0'){
                                var val = 'Synced';
                            }else if(d === '1'){
                                var val = 'Pending';
                            }else if(d === '2'){
                                var val = 'Failed';
                            }
                        }

                        select.append( '<option value="'+d+'">'+val+'</option>' )
                    } );


                }else{

                    if(colIndex !== 8){

                        $('input', this.footer()).on('keyup change', function() {
                            if (that.search() !== this.value) {
                                that
                                    .search(this.value)
                                    .draw();
                            }
                        });

                    }

                }

            });
        }

    } );

    $(".table-striped").find('tr[data-target]').on('click', function(){
        //or do your operations here instead of on show of modal to populate values to modal.
        $('#orderModal').data('id',$(this).data('id'));
    });


    // Handle click on checkbox
    $('#datatable tbody').on('click', 'input[type="checkbox"]', function(e){
        var $row = $(this).closest('tr');

        // Get row data
        var data = table.row($row).data();

        // Get row ID
        var rowId = data['device_id'];

        // Determine whether row ID is in the list of selected row IDs
        var index = $.inArray(rowId, rows_selected);

        // If checkbox is checked and row ID is not in list of selected row IDs
        if(this.checked && index === -1){
            rows_selected.push(rowId);

            // Otherwise, if checkbox is not checked and row ID is in list of selected row IDs
        } else if (!this.checked && index !== -1){
            rows_selected.splice(index, 1);
        }

        if(this.checked){
            $row.addClass('selected');
        } else {
            $row.removeClass('selected');
        }

        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle click on table cells with checkboxes
   // $('#datatable').on('click', 'tbody td, thead th:first-child', function(e){
   //     $(this).parent().find('input[type="checkbox"]').trigger('click');
   // });

    // Handle click on "Select all" control
    $('thead input[name="select_all"]', table.table().container()).on('click', function(e){
        if(this.checked){
            $('#datatable tbody input[type="checkbox"]:not(:checked)').trigger('click');
        } else {
            $('#datatable tbody input[type="checkbox"]:checked').trigger('click');
        }

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle table draw event
    table.on('draw', function(){
        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);
    });

    // Handle form submission event
    $('#frm-example').on('submit', function(e){
        var form = this;

        // Iterate over all selected checkboxes
        $.each(rows_selected, function(index, rowId){
            // Create a hidden element
            $(form).append(
                $('<input>')
                    .attr('type', 'hidden')
                    .attr('name', 'id[]')
                    .val(rowId)
            );
        });
    });


    //
    // Updates "Select all" control in a data table
    //
    function updateDataTableSelectAllCtrl(table){

        var $table             = table.table().node();
        var $chkbox_all        = $('tbody input[type="checkbox"]', $table);
        var $chkbox_checked    = $('tbody input[type="checkbox"]:checked', $table);
        var chkbox_select_all  = $('thead input[name="select_all"]', $table).get(0);

        // If none of the checkboxes are checked
        if($chkbox_checked.length === 0){
            chkbox_select_all.checked = false;
            $('#delete-button').attr('disabled', 'disabled');
            $('#add-devices-networks-button').attr('disabled', 'disabled');
            $('#dropdownBulkActions').attr('disabled', 'disabled');
            $('#validate-button').attr('disabled', 'disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If all of the checkboxes are checked
        } else if ($chkbox_checked.length === $chkbox_all.length){
            chkbox_select_all.checked = true;
            if(rights.deviceDelete){

                $('#delete-button').removeAttr('disabled');

            }

            if(rights.deviceValidate){

                $('#validate-button').removeAttr('disabled');

            }

            $('#add-devices-networks-button').removeAttr('disabled');
            $('#dropdownBulkActions').removeAttr('disabled');


            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If some of the checkboxes are checked
        } else {
            chkbox_select_all.checked = true;
            if(rights.deviceDelete){

                $('#delete-button').removeAttr('disabled');

            }

            $('#add-devices-networks-button').removeAttr('disabled');
            $('#dropdownBulkActions').removeAttr('disabled');

            if(rights.deviceValidate){

                $('#validate-button').removeAttr('disabled');

            }

            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = true;
            }
        }
    }

    $('#datatable tbody').on('click', 'td.details-control', function (e) {

        var table = $('#datatable').DataTable();
        var tr = $(this).closest('tr');
        //console.log(tr);
        var row = table.row( tr );
        //console.log(row);

        var slider = $('#slider');
        slider.html(formatDeviceDetail(row.data()));
        slider.slideReveal({
            position: "right",
            width: 350,
            push: false,
            overlay: true
        });
        slider.css('height','100%');
        slider.css('overflow-y','scroll');
        slider.slideReveal("show");

        e.stopPropagation();

        /*if ( row.child.isShown() ) {
            row.child.hide();
            tr.removeClass('shown');
        }
        else {
            row.child( format(row.data()) ).show();
            tr.addClass('shown');
        }*/
    } );

};

function init_DeviceDataTable(url, typeOfView = null) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatable tfoot th').each( function (i) {

        if(i > 2 && i != 7 && i != 9){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }

    } );

    var table = $('#datatable').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 3, "asc" ]],
        "search": {
            "regex": false
        },
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError

        },
        "columns": [
            {
                className:      'select-checkbox',
                orderable:      false,
                data:           null,
                defaultContent: ''
            },
            {
                className:      'details-control text-center',
                orderable:      false,
                data:           null,
                defaultContent: '<i class="fa fa-plus-circle" style="cursor: pointer;" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Show Device Detail"></i>'
            },
            { "data": "device_type" },
            { "data": "name"},
            { "data": 'ovpn_ip'},
            { "data": 'label'},
            { "data": "network_cnt" },
            { "data": "online"},
            { "data": "sync_status" },
            {
                data: null,
                "render": function (data, type, full, meta) {

                    if(data['device_id']){
                        id = data['device_id'];
                    }else{
                        id = data['id'];
                    }

                    var editUrl = '';

                    if(rights.deviceEdit){

                        //editUrl = Routing.generate('app_edit_device', {'id': id });
                        editUrl = '<a href="#" class="editor_edit" data-id="' + id + '" onclick="saveEditReturn();">Edit</a>';

                    }

                    if(typeOfView == null){

                        var manageDeviceUrl = '';
                        var deleteUrl = '';

                        if(data['proxy_url'] != null && data['proxy_url'] != ''){

                            manageDeviceUrl = '<a href="https://'+data['proxy_url']+'" target="_blank" class="editor_edit">Manage</a>';

                        }

                        if(rights.deviceDelete){

                            deleteUrl = '<a href="#" data-toggle="modal" data-id="'+ id +'" data-target="#removeDeviceModal" data-name="'+data['name']+'" class="editor_remove">Delete</a>';

                        }

                        if(data['validated'] == false){

                            var validateUrl = '';

                            if(rights.deviceValidate){

                                validateUrl = '<a href="#" onclick="javascript:validateDevice(' + id + ')" class="editor_remove">Validate</a>';  //'<a href="'+validatedUrl+'" class="editor_remove">Validate</a>';

                            }

                            return validateUrl;

                        }else{

                            var links = [editUrl, manageDeviceUrl, deleteUrl];

                            return links.filter(function (val) {return val;}).join(' / ');
                        }

                    }else{

                        var leaveNetworkUrl = '';

                        if(rights.deviceNetworkLeave){

                            leaveNetworkUrl =  '<a href="#" data-toggle="modal" data-id="'+ id +'" data-target="#leaveNetworkModal" data-name="'+data['name']+'" data-id="'+ id +'" class="editor_remove">Leave</a>';

                        }

                        var links = [editUrl, leaveNetworkUrl];

                        return links.filter(function (val) {return val;}).join(' / ');

                    }
                }
            }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            {
                'targets': 0,
                'searchable': false,
                'orderable': false,
                'width': '1%',
                'className': 'dt-body-center',
                'render': function (data, type, full, meta){
                    return '<input type="checkbox">';
                }
            },
            {
                "targets": 1,
                'width': '3%',
                "orderable": false
            },
            {
                'targets': 2,
                'width': '10%',
                'render': function (data, type, full, meta){
                    if(data == 1){
                        return 'Standalone Client';
                    }else if(data == 2){
                        return 'Router';
                    }
                    return 'none';
                }
            },
            {
                "targets": 3,
                'width': '20%',
            },
            {
                "targets": 4,
                'width': '10%',
            },
            {
                "targets": 6,
                'className': 'dt-center',
                'width': '5%',
            },
            {
                'targets': 7,
                'className': 'dt-center',
                'width': '7%',
                    //if(full.disabled == 1){
                'render': function (data, type, full, meta){
                    if(data == 0){
                        return '<i class="fa fa-stop" style="color: #bb4a1e" aria-hidden="true"></i> Offline';
                    }else if(data == 1){
                        return '<i class="fa fa-exchange" style="color: #1ABB9C" aria-hidden="true"></i> Online';
                    }else if(data == 2){
                        return '<i class="fa fa-stop" style="color: #d3d6da" aria-hidden="true"></i> Disabled';
                    }

                    return 'none';
                }
            },
            {
                'targets': 8,
                //'className': 'dt-center',
                'width': '7%',
                'render': function (data, type, full, meta){

                    if (full.device_type == 2) { //is it router?
                        if(data == 0){
                            //return '<i class="fa fa-circle " style="color: green" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="OK"></i>';
                            return '<i class="fa fa-circle " style="color: green;padding-left:12%" aria-hidden="true"></i> Synced';
                        }else if(data == 1){
                            //return '<i class="fa fa-circle" style="color: #f9c26f" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Pending"></i>';
                            return '<i class="fa fa-circle" style="color: #f9c26f;padding-left:12%" aria-hidden="true"></i> Pending';
                        }else if(data == 2){
                            //return '<i class="fa fa-circle" style="color: #bb4a1e" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Failed"></i>';
                            return '<i class="fa fa-circle" style="color: #bb4a1e;padding-left:12%" aria-hidden="true"></i> Failed';
                        }
                    }
                    return ''; //not router, show empty string
                }
            },
            {
                "targets": 9,
                'className': 'actions',
                "orderable": false,
                'searchable': false,
                'width': '10%',
            },
        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
            var api = this.api();

            // Apply the search
            api.columns().every(function(index) {
                var that = this;

                var colIndex = index;

                if (colIndex === 2 || colIndex === 7 || colIndex === 8){

                    var column = this;
                    var select = $('<select><option value=""></option></select>')
                        .appendTo( $(column.footer()).empty() )
                        .on( 'change', function () {
                            var val = $.fn.dataTable.util.escapeRegex(
                                $(this).val()
                            );

                            column
                            //.search( val ? '^'+val+'$' : '', true, false )
                                .search( $(this).val() )
                                .draw();
                        } );

                    column.data().unique().sort().each( function ( d, j) {

                        if(colIndex == 2){//Device Type

                            var append = true;

                            if (d === '1'){
                                var val = 'Standalone Client';
                            }else if(d === '2'){
                                var val = 'Router';
                            }
                        }

                        if(colIndex == 7){//Connected

                            var append = true;

                            if (d === '0'){
                                var val = 'Offline';
                            }else if(d === '1'){
                                var val = 'Online';
                            }else if(d === '2'){
                                var val = 'Disabled';
                            }
                        }

                        if(colIndex == 8){//Synced
                            if (d === '0'){
                                var val = 'Synced';
                                var append = true;
                            }else if(d === '1'){
                                var val = 'Pending';
                                var append = true;
                            }else if(d === '2'){
                                var val = 'Failed';
                                var append = true;
                            }else if(d === ''){
                                var append = false;
                            }
                        }

                        if(append){
                            select.append( '<option value="'+d+'">'+val+'</option>' )
                        }

                    } );




                }else{

                    if(colIndex !== 9){

                        $('input', this.footer()).on('keyup change', function() {
                            if (that.search() !== this.value) {
                                that
                                    .search(this.value)
                                    .draw();
                            }
                        });

                    }

                }

            });
        }

    } );

    $(".table-striped").find('tr[data-target]').on('click', function(){
        //or do your operations here instead of on show of modal to populate values to modal.
        $('#orderModal').data('id',$(this).data('id'));
    });


    // Handle click on checkbox
    $('#datatable tbody').on('click', 'input[type="checkbox"]', function(e){
        var $row = $(this).closest('tr');

        // Get row data
        var data = table.row($row).data();

        // Get row ID
        var rowId = data['device_id'];

        // Determine whether row ID is in the list of selected row IDs
        var index = $.inArray(rowId, rows_selected);

        // If checkbox is checked and row ID is not in list of selected row IDs
        if(this.checked && index === -1){
            rows_selected.push(rowId);

            // Otherwise, if checkbox is not checked and row ID is in list of selected row IDs
        } else if (!this.checked && index !== -1){
            rows_selected.splice(index, 1);
        }

        if(this.checked){
            $row.addClass('selected');
        } else {
            $row.removeClass('selected');
        }

        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle click on table cells with checkboxes
    // $('#datatable').on('click', 'tbody td, thead th:first-child', function(e){
    //     $(this).parent().find('input[type="checkbox"]').trigger('click');
    // });

    // Handle click on "Select all" control
    $('thead input[name="select_all"]', table.table().container()).on('click', function(e){
        if(this.checked){
            $('#datatable tbody input[type="checkbox"]:not(:checked)').trigger('click');
        } else {
            $('#datatable tbody input[type="checkbox"]:checked').trigger('click');
        }

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle table draw event
    table.on('draw', function(){
        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);
    });

    // Handle form submission event
    $('#frm-example').on('submit', function(e){
        var form = this;

        // Iterate over all selected checkboxes
        $.each(rows_selected, function(index, rowId){
            // Create a hidden element
            $(form).append(
                $('<input>')
                    .attr('type', 'hidden')
                    .attr('name', 'id[]')
                    .val(rowId)
            );
        });
    });


    //
    // Updates "Select all" control in a data table
    //
    function updateDataTableSelectAllCtrl(table){

        var $table             = table.table().node();
        var $chkbox_all        = $('tbody input[type="checkbox"]', $table);
        var $chkbox_checked    = $('tbody input[type="checkbox"]:checked', $table);
        var chkbox_select_all  = $('thead input[name="select_all"]', $table).get(0);

        // If none of the checkboxes are checked
        if($chkbox_checked.length === 0){
            chkbox_select_all.checked = false;
            $('#delete-button').attr('disabled', 'disabled');
            $('#add-devices-networks-button').attr('disabled', 'disabled');
            $('#dropdownBulkActions').attr('disabled', 'disabled');
            $('#validate-button').attr('disabled', 'disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If all of the checkboxes are checked
        } else if ($chkbox_checked.length === $chkbox_all.length){
            chkbox_select_all.checked = true;
            if(rights.deviceDelete){

                $('#delete-button').removeAttr('disabled');

            }

            if(rights.deviceValidate){

                $('#validate-button').removeAttr('disabled');

            }

            $('#add-devices-networks-button').removeAttr('disabled');
            $('#dropdownBulkActions').removeAttr('disabled');


            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If some of the checkboxes are checked
        } else {
            chkbox_select_all.checked = true;
            if(rights.deviceDelete){

                $('#delete-button').removeAttr('disabled');

            }

            $('#add-devices-networks-button').removeAttr('disabled');
            $('#dropdownBulkActions').removeAttr('disabled');

            if(rights.deviceValidate){

                $('#validate-button').removeAttr('disabled');

            }

            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = true;
            }
        }
    }

    $('#datatable tbody').on('click', 'td.details-control', function (e) {

        var table = $('#datatable').DataTable();
        var tr = $(this).closest('tr');
        //console.log(tr);
        var row = table.row( tr );
        //console.log(row);

        var slider = $('#slider');
        slider.html(formatDeviceDetail(row.data()));
        slider.slideReveal({
            position: "right",
            width: 350,
            push: false,
            overlay: true
        });
        slider.css('height','100%');
        slider.css('overflow-y','scroll');
        slider.slideReveal("show");

        e.stopPropagation();

        /*if ( row.child.isShown() ) {
            row.child.hide();
            tr.removeClass('shown');
        }
        else {
            row.child( format(row.data()) ).show();
            tr.addClass('shown');
        }*/
    } );

};

function handleAjaxError( jqXHR, textStatus, error ) {

    switch (jqXHR.status) {
        case 401:
            var redirectUrl = Routing.generate('fos_user_security_login');
            window.location.replace(redirectUrl);
            break;
        case 403:
            notify('Action not allowed', 'You have no rights to do that.', 'info');
            break;
        default:
            notify('Error', 'Something bad happened.', 'error');
    }

}

function init_NetworkDataTable(url) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatable tfoot th').each( function (i) {
        if(i > 1 && i != 4){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }
    } );

    var table = $('#datatable').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 2, "asc" ]],
        "search": {
            "regex": false
        },
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError
        },
        "columns": [
            {
                className:      'select-checkbox',
                data:           null,
                defaultContent: ''
            },
            {
                className:      'details-control text-center',
                data:           null,
                defaultContent: '<i class="fa fa-plus-circle" style="cursor: pointer;" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Show Network Detail"></i>'
            },
            { "data": "name" },
            { "data": "device_cnt" },
            {
                data: null,
                "render": function (data, type, full, meta) {

                    id = data['network_id'];
                    editUrl = '';
                    deleteUrl = '';

                    if(rights.networkEdit){

                        editUrl = Routing.generate('app_edit_network', {'id': data['network_id'] });
                        editUrl = '<a href="' + editUrl + '" class="editor_edit">Edit</a>';

                    }

                    if(rights.networkDelete){

                        deleteUrl = '<a href="#" data-toggle="modal" data-id="' + id + '" data-target="#removeNetworkModal" data-name="'+data['name']+'" class="editor_remove">Delete</a>';

                    }

                    detailUrl = Routing.generate('app_network_detail', {'id': data['network_id'] });
                    detailUrl = '<a href="' + detailUrl  +'" class="editor_edit">Devices</a>';

                    var links = [detailUrl, editUrl, deleteUrl];

                    return links.filter(function (val) {return val;}).join(' / ');
                }
            }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            {
                "searchable": false,
                "targets": [ 1,3,4 ]
            },
            {
                "orderable": false,
                "targets": [ 1,4 ]
            },
            {
                'targets': 0,
                'orderable': false,
                'width': '1%',
                'className': 'dt-body-center',
                'render': function (data, type, full, meta){
                    return '<input type="checkbox">';
                }
            },
            {
                "targets": 1,
                'width': '3%',
                "orderable": false
            },
            {
                "targets": 2,
                'width': '60%'
            },
            {
                "targets": 3,
                'width': '20%',
            },
            {
                "targets": 4,
                'className': 'actions',
                'width': '10%'
            },

        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
            var api = this.api();

            // Apply the search
            api.columns().every(function(index) {
                var that = this;

                var colIndex = index;

                if (index === 4 || index === 5){


                }else{

                    $('input', this.footer()).on('keyup change', function() {
                        if (that.search() !== this.value) {
                            that
                                .search(this.value)
                                .draw();
                        }
                    });

                }

            });
        }

    } );

    // Handle click on checkbox
    $('#datatable tbody').on('click', 'input[type="checkbox"]', function(e){
        var $row = $(this).closest('tr');

        // Get row data
        var data = table.row($row).data();

        // Get row ID
        var rowId = data['network_id'];

        // Determine whether row ID is in the list of selected row IDs
        var index = $.inArray(rowId, rows_selected);

        // If checkbox is checked and row ID is not in list of selected row IDs
        if(this.checked && index === -1){
            rows_selected.push(rowId);

            // Otherwise, if checkbox is not checked and row ID is in list of selected row IDs
        } else if (!this.checked && index !== -1){
            rows_selected.splice(index, 1);
        }

        if(this.checked){
            $row.addClass('selected');
        } else {
            $row.removeClass('selected');
        }

        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle click on table cells with checkboxes
    //$('#datatable').on('click', 'tbody td, thead th:first-child', function(e){
    //    $(this).parent().find('input[type="checkbox"]').trigger('click');
    //});

    // Handle click on "Select all" control
    $('thead input[name="select_all"]', table.table().container()).on('click', function(e){
        if(this.checked){
            $('#datatable tbody input[type="checkbox"]:not(:checked)').trigger('click');
        } else {
            $('#datatable tbody input[type="checkbox"]:checked').trigger('click');
        }

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle table draw event
    table.on('draw', function(){
        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);
    });

    // Handle form submission event
    $('#frm-example').on('submit', function(e){
        var form = this;

        // Iterate over all selected checkboxes
        $.each(rows_selected, function(index, rowId){
            // Create a hidden element
            $(form).append(
                $('<input>')
                    .attr('type', 'hidden')
                    .attr('name', 'id[]')
                    .val(rowId)
            );
        });
    });


    //
    // Updates "Select all" control in a data table
    //
    function updateDataTableSelectAllCtrl(table){

        var $table             = table.table().node();
        var $chkbox_all        = $('tbody input[type="checkbox"]', $table);
        var $chkbox_checked    = $('tbody input[type="checkbox"]:checked', $table);
        var chkbox_select_all  = $('thead input[name="select_all"]', $table).get(0);

        // If none of the checkboxes are checked
        if($chkbox_checked.length === 0){
            chkbox_select_all.checked = false;
            $('#delete-button').attr('disabled', 'disabled');
            //$('#add-devices-networks-button').attr('disabled', 'disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If all of the checkboxes are checked
        } else if ($chkbox_checked.length === $chkbox_all.length){
            chkbox_select_all.checked = true;
            $('#delete-button').removeAttr('disabled');
            //$('#add-devices-networks-button').removeAttr('disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If some of the checkboxes are checked
        } else {
            chkbox_select_all.checked = true;
            $('#delete-button').removeAttr('disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = true;
            }
        }
    }

    $('#datatable tbody').on('click', 'td.details-control', function (e) {

        var table = $('#datatable').DataTable();
        var tr = $(this).closest('tr');
        //console.log(tr);
        var row = table.row( tr );
        //console.log(row);

        var slider = $('#slider');
        slider.html(formatNetworkDetail(row.data()));
        slider.slideReveal({
            position: "right",
            width: 350,
            push: false,
            overlay: true
        });
        slider.css('height','100%');
        slider.css('overflow-y','scroll');
        slider.slideReveal("show");

        e.stopPropagation();

        /*if ( row.child.isShown() ) {
            row.child.hide();
            tr.removeClass('shown');
        }
        else {
            row.child( format(row.data()) ).show();
            tr.addClass('shown');
        }*/
    } );

};

function init_StandaloneVpnClientDataTable(url) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatable tfoot th').each( function (i) {

        if(i > 1 && i != 6 && i != 8){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }

    } );

    var table = $('#datatable').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 2, "asc" ]],
        "search": {
            "regex": false
        },
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError
        },
        "columns": [
            {
                className:      'select-checkbox',
                orderable:      false,
                data:           null,
                defaultContent: ''
            },
            {
                className:      'details-control text-center',
                orderable:      false,
                data:           null,
                defaultContent: '<i class="fa fa-plus-circle" style="cursor: pointer;" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Show Device Detail"></i>'
            },
            { "data": "name" },
            { "data": 'ovpn_ip'},
            { "data": 'label'},
            { "data": 'network_cnt'},
            { //"data": 'expiration_date'
                data: null,
                'render': function (data, type, full, meta){
                    var expiration = new Date(data['expiration_date'] * 1000);
                    var now = Date.now();
                    if (now > expiration) {
                        var red = 'color:#bb4a1e';
                    } else {
                        var red = '';
                    }
                    var dd = expiration.getDate();
                    var MM = expiration.getMonth() + 1; //January is 0!
                    var yyyy = expiration.getFullYear();
                    var hh = expiration.getHours();
                    var mm = expiration.getMinutes();
                    if (dd < 10) {
                        dd = '0' + dd;
                    }
                    if (MM < 10) {
                        MM = '0' + MM;
                    }
                    if (hh < 10) {
                        hh = '0' + hh;
                    }
                    if (mm < 10) {
                        mm = '0' + mm;
                    }
                    return '<span style="line-height:0px;' + red + '">' + dd + '.' + MM + '.' + yyyy + ' ' + hh + ':' + mm + '</span>';
                    //const getLang = () => navigator.language || navigator.browserLanguage || ( navigator.languages || [ "en" ] ) [ 0 ];
                    //console.log(getLang());
                    //console.log(expiration.toLocaleDateString(getLang(), { timeStyle: 'medium'}));
                }
            },
            { "data": "online",
                /*
                data: null,

                'render': function (data, type, full, meta){
                    if(data['disabled'] == 1){
                        return '<i class="fa fa-stop" style="color: #d3d6da" aria-hidden="true"></i> Disabled';
                    } else {
                        if(data['online'] == 0){
                            return '<i class="fa fa-stop" style="color: #bb4a1e" aria-hidden="true"></i> Offline';
                        }else if(data['online'] == 1){
                            return '<i class="fa fa-exchange" style="color: #1ABB9C" aria-hidden="true"></i> Online';
                        }
                    }
                    return 'none';
                }
                 */
            },
            {
                data: null,
                "render": function (data, type, full, meta) {

                    var id = data['device_id'];
                    var downloadFile = data['config_file_path'];

                    var editUrl = '';
                    if(rights.deviceEdit){
                        // editUrl = Routing.generate('app_edit_device', {'id': id });
                        // editUrl = '<a href="' + editUrl + '" class="editor_edit" onclick="saveEditReturn()">Edit</a>';
                        editUrl = '<a href="#" class="editor_edit" data-id="' + id + '" onclick="saveEditReturn();">Edit</a>';
                    }

                    var deleteUrl = '';
                    if(rights.standaloneVpnClientDelete){

                        deleteUrl = '<a href="#" data-toggle="modal" data-id="'+ id +'" data-target="#removeStandaloneVpnClientModal" data-name="'+data['name']+'" class="editor_remove">Delete</a>';

                    }

                    var downloadUrl = '';
                    if(rights.standaloneVpnClientDownload){

                        downloadUrl = '<a href="#" onclick="javascript:downloadStandaloneVpnClientConfigFile(\'' + downloadFile + '\')" class="editor_remove">Download Config</a>';

                    }

                    var links = [editUrl, deleteUrl, downloadUrl];

                    return links.filter(function (val) {return val;}).join(' / ');

                }
            }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            {
                'targets': 0,
                'searchable': false,
                'orderable': false,
                'width': '1%',
                'className': 'dt-body-center',
                'render': function (data, type, full, meta){
                    return '<input type="checkbox">';
                }
            },
            {
                "targets": 1,
                'searchable': false,
                'orderable': false,
                'width': '3%',
            },
            {
                "targets": 2,
                'width': '20%',
            },
            {
                "targets": 3,
                'width': '10%',
            },
            {
                "targets": 5,//networks
                'className': 'dt-center',
                'width': '5%',
            },
            {
                "targets": 6,//expires
                'width': '10%',
                'searchable': false,
            },
            {
                "targets": 7,
                'className': 'dt-center',
                'width': '1%',
                'render': function (data, type, full, meta){
                    if(data == 0){
                        return '<i class="fa fa-stop" style="color: #bb4a1e" aria-hidden="true"></i> Offline';
                    }else if(data == 1){
                        return '<i class="fa fa-exchange" style="color: #1ABB9C" aria-hidden="true"></i> Online';
                    }else if(data == 2){
                        return '<i class="fa fa-stop" style="color: #d3d6da" aria-hidden="true"></i> Disabled';
                    }

                    return 'none';
                }
            },
            {
                "targets": 8,
                'className': 'actions',
                'searchable': false,
                "orderable": false,
                'width': '15%',
            },
        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            //fix: this helped uncheck the checkbox after action was done
                //var rowId = data['device_id'];
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
            var api = this.api();

            // Apply the search
            api.columns().every(function(index) {
                var that = this;

                var colIndex = index;

                if (colIndex === 7){

                    var column = this;
                    var select = $('<select><option value=""></option></select>')
                        .appendTo( $(column.footer()).empty() )
                        .on( 'change', function () {
                            var val = $.fn.dataTable.util.escapeRegex(
                                $(this).val()
                            );

                            column
                            //.search( val ? '^'+val+'$' : '', true, false )
                                .search( $(this).val() )
                                .draw();
                        } );

                    column.data().unique().sort().each( function ( d, j) {

                        if(colIndex == 7){

                            if (d === '0'){
                                var val = 'Offline';
                            }else if(d === '1'){
                                var val = 'Online';
                            }else if(d === '2'){
                                var val = 'Disabled';
                            }

                        }

                        select.append( '<option value="'+d+'">'+val+'</option>' )
                    } );


                }else{

                    if(colIndex !== 8){

                        $('input', this.footer()).on('keyup change', function() {
                            if (that.search() !== this.value) {
                                that
                                    .search(this.value)
                                    .draw();
                            }
                        });

                    }

                }

            });
        }

    } );

    // Handle click on checkbox
    $('#datatable tbody').on('click', 'input[type="checkbox"]', function(e){
        var $row = $(this).closest('tr');

        // Get row data
        var data = table.row($row).data();

        // Get row ID
        var rowId = data['device_id'];

        // Determine whether row ID is in the list of selected row IDs
        var index = $.inArray(rowId, rows_selected);

        // If checkbox is checked and row ID is not in list of selected row IDs
        if(this.checked && index === -1){
            rows_selected.push(rowId);

            // Otherwise, if checkbox is not checked and row ID is in list of selected row IDs
        } else if (!this.checked && index !== -1){
            rows_selected.splice(index, 1);
        }

        if(this.checked){
            $row.addClass('selected');
        } else {
            $row.removeClass('selected');
        }

        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle click on "Select all" control
    $('thead input[name="select_all"]', table.table().container()).on('click', function(e){
        if(this.checked){
            $('#datatable tbody input[type="checkbox"]:not(:checked)').trigger('click');
        } else {
            $('#datatable tbody input[type="checkbox"]:checked').trigger('click');
        }

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle table draw event
    table.on('draw', function(){
        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);
    });

    // Handle form submission event
    $('#frm-example').on('submit', function(e){
        var form = this;

        // Iterate over all selected checkboxes
        $.each(rows_selected, function(index, rowId){
            // Create a hidden element
            $(form).append(
                $('<input>')
                    .attr('type', 'hidden')
                    .attr('name', 'id[]')
                    .val(rowId)
            );
        });
    });


    //
    // Updates "Select all" control in a data table
    //
    function updateDataTableSelectAllCtrl(table){
        var $table             = table.table().node();
        var $chkbox_all        = $('tbody input[type="checkbox"]', $table);
        var $chkbox_checked    = $('tbody input[type="checkbox"]:checked', $table);
        var chkbox_select_all  = $('thead input[name="select_all"]', $table).get(0);

        // If none of the checkboxes are checked
        if($chkbox_checked.length === 0){
            chkbox_select_all.checked = false;
            $('#add-devices-networks-button').attr('disabled', 'disabled');
            $('#dropdownBulkActions').attr('disabled', 'disabled');
            $('#delete-button').attr('disabled', 'disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If all of the checkboxes are checked
        } else if ($chkbox_checked.length === $chkbox_all.length){
            chkbox_select_all.checked = true;
            $('#add-devices-networks-button').removeAttr('disabled');
            $('#dropdownBulkActions').removeAttr('disabled');
            $('#delete-button').removeAttr('disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = false;
            }

            // If some of the checkboxes are checked
        } else {
            chkbox_select_all.checked = true;
            $('#add-devices-networks-button').removeAttr('disabled');
            $('#dropdownBulkActions').removeAttr('disabled');
            $('#delete-button').removeAttr('disabled');
            if('indeterminate' in chkbox_select_all){
                chkbox_select_all.indeterminate = true;
            }
        }
    }

    $('#datatable tbody').on('click', 'td.details-control', function (e) {

        var table = $('#datatable').DataTable();
        var tr = $(this).closest('tr');
        //console.log(tr);
        var row = table.row( tr );
        //console.log(row);

        var slider = $('#slider');
        slider.html(formatDeviceDetail(row.data()));
        slider.slideReveal({
            position: "right",
            width: 350,
            push: false,
            overlay: true
        });
        slider.css('height','100%');
        slider.css('overflow-y','scroll');
        slider.slideReveal("show");

        e.stopPropagation();

        /*if ( row.child.isShown() ) {
            row.child.hide();
            tr.removeClass('shown');
        }
        else {
            row.child( format(row.data()) ).show();
            tr.addClass('shown');
        }*/
    } );

};

function init_PrevalidationDataTable(url) {

    $('#datatable tfoot th').each( function (i) {
                    var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
    } );

    var table = $('#datatable').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 0, "asc" ]],
        "search": {
            "regex": false
        },
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError
        },
        "columns": [
            { "data": "serial" },
            { "data": "mac" },
            { "data": "imei" },
            { "data": "name" }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
/*
        "columnDefs": [
            {
                "targets": 0,
                'width': '25%',
            },
            {
                "targets": 1,
                'width': '25%'
            },
            {
                "targets": 2,
                'width': '25%',
            },
            {
                "targets": 3,
                'width': '25%',
            },


        ],*/

        initComplete: function() {
            var api = this.api();

            // Apply the search
            api.columns().every(function() {
                var that = this;

                    $('input', this.footer()).on('keyup change', function() {
                        if (that.search() !== this.value) {
                            that
                                .search(this.value)
                                .draw();
                        }
                    });
            });
        }
    } );

    // Handle table draw event

    table.on('draw', function(){
        // Update state of "Select all" control
        updateDataTable(table);
    });

    //
    // Updates "Select all" control in a data table
    //

    function updateDataTable(table){

        var $table             = table.table().node();

    }

};


function reload_table(){

    $('#datatable').DataTable().ajax.reload(null, false);

};

window.setTimeout(function() {
    $("#msgs").fadeTo(500, 0).slideUp(500, function(){
        $(this).remove();
    });
}, 3000);

function set_auto_refresh(time, el, tableName = 'datatable'){
    var value = 0;
    window.eval(tableName+" = '"+value+"';");
    $(selel).removeClass('selected');
    selel = el;
    $(el).addClass('selected');
    clearInterval(eval(tableName));
    eval(tableName+" = '"+setInterval( function () {
        $('#'+tableName).DataTable().ajax.reload(null, false);
    }, time )+"';");

};

function stop_auto_refresh(el, tableName = 'datatable') {
    $(selel).removeClass('selected');
    selel = el;
    $(el).addClass('selected');
    clearInterval(window.eval(tableName));
}

function validateDevices() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.device_id
    });

    if(ids.length == 0){

        notify('Router validation', 'No Router selected.');

    }else{

        $.ajax({
            type: "POST",
            url: routes.ajax.devicesValidate,
            data: "{\"ids\":[" + ids + "]}",
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(data) {

                if(data['status'] == 'success'){

                    notify('Routers validated', 'Selected Routers were validated.', 'success');

                }else{

                    notify('Routers validation failed', data['errtext'], 'error');

                }

                table.ajax.reload(null, false);
            },
            error: function(jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('Routers validation failed', 'Something bad happened.', 'error');
                }

            }
        });

    }

}

function deleteDevices() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.device_id
    });

    if(ids.length == 0){

        notify('Delete devices', 'No device selected.');

    }else{

        $.ajax({
            type: "POST",
            url: Routing.generate('app_ajax_remove_devices'),
            data: "{\"ids\":[" + ids + "]}",
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(data) {

                if(data['status'] == 'success'){

                    notify('Delete devices', 'Selected devices were deleted.', 'success');

                }else{

                    notify('Devices delete failed', 'Deletion of selected devices failed.', 'error');

                }

                table.ajax.reload(null, false);
            },
            error: function(jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('Devices delete failed', 'Something bad happened.', 'error');
                }

            }
        });

    }

}

function disableDevices() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.device_id
    });

    if(ids.length == 0){

        notify('VPN Access disable', 'No device selected.');

    }else{

        $.ajax({
            type: "POST",
            url: Routing.generate('app_ajax_disable_devices'),
            data: "{\"ids\":[" + ids + "]}",
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(data) {

                if(data['status'] == 'success'){

                    notify('VPN Access disabled', 'Selected devices were disabled.', 'success');

                }else{

                    notify('VPN Access disable failed', 'Disabling of selected devices failed.', 'error');

                }

                table.ajax.reload(null, false);
            },
            error: function(jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('VPN Access disable failed', 'Something bad happened.', 'error');
                }

            }
        });

    }

}

function enableDevices() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.device_id
    });

    if(ids.length == 0){

        notify('VPN Access enable', 'No device selected.');

    }else{

        $.ajax({
            type: "POST",
            url: Routing.generate('app_ajax_enable_devices'),
            data: "{\"ids\":[" + ids + "]}",
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(data) {

                if(data['status'] == 'success'){

                    notify('VPN Access enabled', 'Selected devices were enabled.', 'success');

                }else{

                    notify('VPN Access enable failed', 'Enabling of selected devices failed.', 'error');

                }

                table.ajax.reload(null, false);
            },
            error: function(jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('VPN Access enable failed', 'Something bad happened.', 'error');
                }

            }
        });

    }

}

function validateDevice(id) {

    var table = $('#datatable').DataTable();

    $.ajax({
        type: "GET",
        url: Routing.generate('app_ajax_validate_device', {'id': id}),
        contentType: "application/json; charset=utf-8",
        dataType: "json",
        success: function(data) {

            if(data['status'] == 'success'){

                notify('Router validated', data['msg'], 'success');

            }else{

                notify('Router validation failed', data['msg'], 'error');

            }

            table.ajax.reload(null, false);

        },
        error: function(jqXHR, textStatus, errorThrown) {

            switch (jqXHR.status) {
                case 401:
                    var redirectUrl = Routing.generate('fos_user_security_login');
                    window.location.replace(redirectUrl);
                    break;
                case 403: // (Invalid CSRF token for example)
                    notify('Action not allowed', 'You have no rights to do that.', 'info');
                    break;
                default:
                    notify('Routers validation failed', 'Something bad happened.', 'error');
            }

            table.ajax.reload(null, false);

        }

    });

}

function deleteNetworks() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.network_id
    });

    if(ids.length == 0){

        notify('Delete networks', 'No network selected.');

    }else{

        $.ajax({
            type: "POST",
            url: Routing.generate('app_ajax_remove_networks'),
            data: "{\"ids\":[" + ids + "]}",
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(data) {

                if(data['status'] == 'success'){

                    notify('Delete networks', 'Selected networks were deleted.', 'success');

                }else{

                    notify('Networks delete failed', 'Deletion of selected networks failed.', 'error');

                }

                table.ajax.reload(null, false);
            },
            error: function(jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('Networks delete failed', 'Something bad happened.', 'error');
                }
            }
        });

    }

}

function addDevices() {

    var full_url = document.URL; // Get current url
    var url_array = full_url.split('/') // Split the string into an array with / as separator
    var networkId = getPathFromUrl(url_array[url_array.length-1]);  // Get the last part of the array (-1)

    console.log(networkId);
    select = $('#devices').multipleSelect();
    select.append(new Option('Loading...'));
    $('#devices').multipleSelect('disable');
    $('#devices').multipleSelect('refresh');
    $('#addDeviceModal').modal();

    $.ajax({
        type: "GET",
        url: Routing.generate('app_ajax_available_devices_network', {'id': networkId}),
        contentType: "application/json; charset=utf-8",
        dataType: "json",
        success: function(data) {

            if(data['status'] == 'success'){

                $('#devices').multipleSelect('enable');

                //console.log(data);


                selectValues = data['data'];

                select.empty();
                $.each(selectValues, function (index, item) {
                    select.append(new Option(index, item));
                });

                $('#devices').multipleSelect('refresh');

            }else{

                notify('Error on getting devices.', data['msg'], 'error');

            }

        },
        error: function(jqXHR, textStatus, errorThrown) {

            switch (jqXHR.status) {
                case 401:
                    var redirectUrl = Routing.generate('fos_user_security_login');
                    window.location.replace(redirectUrl);
                    break;
                case 403: // (Invalid CSRF token for example)
                    notify('Action not allowed', 'You have no rights to do that.', 'info');
                    break;
                default:
                    notify('Error on getting devices', 'Something bad happened.', 'error');
            }

        }

    });

}

function getPathFromUrl(url) {
    //Remove hash adn query string
    return url.split(/[?#]/)[0];
}

function addDevicesToNetwork() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.device_id
    });

    if(ids.length == 0){

        notify('Add Routers to the network', 'No Router selected.');

    }else {

        select = $('#networks').multipleSelect();
        select.append(new Option('Loading...'));
        $('#networks').multipleSelect('disable');
        $('#networks').multipleSelect('refresh');
        $('#addDevicesToNetworkModal').modal();

        $.ajax({
            type: "GET",
            url: Routing.generate('app_ajax_available_networks'),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function (data) {

                if (data['status'] == 'success') {

                    $('#networks').multipleSelect('enable');

                    selectValues = data['data'];

                    select.empty();
                    $.each(selectValues, function (index, item) {
                        select.append(new Option(index, item));
                    });

                    $('#networks').multipleSelect('refresh');

                } else {

                    notify('Error on getting networks.', data['msg'], 'error');

                }

            },
            error: function (jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('Error on getting devices', 'Something bad happened.', 'error');
                }

            }

        });
    }

}

function deleteStandaloneVpnClients() {

    var table = $('#datatable').DataTable();
    var ids = $.map(table.rows('.selected').data(), function (item) {
        return item.device_id
    });

    if(ids.length == 0){

        notify('Delete Standalone VPN Clients', 'No Standalone VPN Clients selected.');

    }else{

        $.ajax({
            type: "POST",
            url: Routing.generate('app_ajax_remove_standalone_vpn_clients'),
            data: "{\"ids\":[" + ids + "]}",
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(data) {

                if(data['status'] == 'success'){

                    notify('Delete Standalone VPN Clients', 'Selected Standalone VPN Clients were deleted.', 'success');

                }else{

                    notify('Delete Standalone VPN Clients', 'Selected  Standalone VPN Clients delete failed.', 'error');

                }

                table.ajax.reload(null, false);
            },
            error: function(jqXHR, textStatus, errorThrown) {

                switch (jqXHR.status) {
                    case 401:
                        var redirectUrl = Routing.generate('fos_user_security_login');
                        window.location.replace(redirectUrl);
                        break;
                    case 403: // (Invalid CSRF token for example)
                        notify('Action not allowed', 'You have no rights to do that.', 'info');
                        break;
                    default:
                        notify('Delete Road Warriors failed', 'Something bad happened.', 'error');
                }

            }
        });

    }

}

function downloadStandaloneVpnClientConfigFile(downloadFile) {

    var table = $('#datatable').DataTable();

    var filename = downloadFile.substring(downloadFile.lastIndexOf('/')+1);

    $.ajax({
        type: "GET",
        url: Routing.generate('app_ajax_download_config_file', {'downloadFile': downloadFile}),
        dataType: "binary",
        success: function(result) {
            var url = URL.createObjectURL(result);
            var $a = $('<a />', {
                'href': url,
                'download': filename,
                'text': "click"
            }).hide().appendTo("body")[0].click();

            // URL.revokeObjectURL(url);
        },
        error: function(jqXHR, textStatus, errorThrown) {

            switch (jqXHR.status) {
                case 401:
                    var redirectUrl = Routing.generate('fos_user_security_login');
                    window.location.replace(redirectUrl);
                    break;
                case 403: // (Invalid CSRF token for example)
                    notify('Action not allowed', 'You have no rights to do that.', 'info');
                    break;
                default:
                    notify('File Download failed', 'Something bad happened.', 'error');
            }

            table.ajax.reload(null, false);

        }

    });

}

function notify(title, text, type = 'info') {

    new PNotify({
        title: title,
        text: text,
        type: type,
        nonblock: {
            nonblock: true
        },

        styling: 'bootstrap3',
    });

}

//FW rules DataTable
function init_DeviceFwRulesDataTable(url, typeOfView = null) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatableDeviceFwRules tfoot th').each( function (i) {

        /*if(i > 1 && i != 6 && i != 8){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }*/

    } );

    var table = $('#datatableDeviceFwRules').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 0, "asc" ]],
        "search": {
            "regex": false
        },
        "lengthChange": false,
        "pageLength": "All",
        'paging': false,
        //"asStripeClasses": ['test'],
        'rowsGroup': ['name:name','policy:name'],
        //"ordering": false,
        /*rowGroup: {
            startRender: null,
            endRender: function ( rows, group ) {

                return $('<tr/>')
                    .append( '<td colspan="3">Averages for '+group+'</td>' )
                    .append( '<td></td>' )
                    .append( '<td/>' )
                    .append( '<td></td>' );
            },
            dataSrc: name,
        },*/
        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError

        },
        "columns": [
            /*{
                className:      'select-checkbox',
                orderable:      false,
                data:           null,
                defaultContent: ''
            },*/
            { "data": "name",
                'name': 'name',
                'render': function(data, type, row){
                    if(rights.deviceEdit){
                        return '<b>'+data+'</b><p><a class="btn btn-info" style="padding: 2px 5px; margin-top:6px; margin-left: 5px;" href="'+Routing.generate('app_edit_device', {'id': row['id'] })+'#fw-rules">Edit</a></p>';
                    } else {
                        return '<b>'+data+'</b>';
                    }


                }
            },
            {"data": "policy",
                'name': 'policy',
            },
            { "data": 'related_policy',
                'render': function(data){

                    if(data == '0'){
                        return '<div style="color: red;">Drop</div>';
                    }else{
                        return '<div style="color: green;">Accept</div>';
                    }

                }
            },
            { "data": 'protocol'},
            { "data": "src_ips" },
            { "data": "dst_ips" },
            { "data": "ports" },
            { "data": "enabled" }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            { orderable: false, targets: [1,2,3,4,5,6] },
            { searchable: false, targets: [1,2,3,4,5,6] },
            {
                "targets": 0,
                'width': '10%',
                'className': 'dt-center',
            },
            {
                "targets": 1,
                'width': '5%',
                'className': 'dt-center',
            },
            {
                "targets": 2,
                'width': '5%',
                'className': 'dt-center',
            },
            {
                "targets": 3,
                'className': 'dt-center',
                'width': '5%',
            },
            {
                "targets": 4,
                //'className': 'dt-center',
                'width': '20%',
            },
            {
                "targets": 5,
                //'className': 'dt-center',
                'width': '20%',
            },
            {
                "targets": 6,
                'width': '20%',
            },
            {
                'targets': 7,
                'className': 'dt-center',
                'width': '1%',
                'render': function (data, type, full, meta){
                    if(data == 0){
                        return '<i class="fa fa-stop" style="color: #bb4a1e" aria-hidden="true"></i><br> Disabled';
                    }else if(data == 1){
                        return '<i class="fa fa-play" style="color: #1ABB9C" aria-hidden="true"></i><br> Enabled';
                    }

                    return 'none';
                }
            },
        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
        }

    } );

    $(".table-striped").find('tr[data-target]').on('click', function(){
        //or do your operations here instead of on show of modal to populate values to modal.
        $('#orderModal').data('id',$(this).data('id'));
    });


    // Handle click on checkbox
    $('#datatableDeviceFwRules tbody').on('click', 'input[type="checkbox"]', function(e){
        var $row = $(this).closest('tr');

        // Get row data
        var data = table.row($row).data();

        // Get row ID
        var rowId = data['device_id'];

        // Determine whether row ID is in the list of selected row IDs
        var index = $.inArray(rowId, rows_selected);

        // If checkbox is checked and row ID is not in list of selected row IDs
        if(this.checked && index === -1){
            rows_selected.push(rowId);

            // Otherwise, if checkbox is not checked and row ID is in list of selected row IDs
        } else if (!this.checked && index !== -1){
            rows_selected.splice(index, 1);
        }

        if(this.checked){
            $row.addClass('selected');
        } else {
            $row.removeClass('selected');
        }

        // Update state of "Select all" control
        updateDataTableSelectAllCtrl(table);

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });

    // Handle click on table cells with checkboxes
    // $('#datatable').on('click', 'tbody td, thead th:first-child', function(e){
    //     $(this).parent().find('input[type="checkbox"]').trigger('click');
    // });

    // Handle click on "Select all" control
    $('thead input[name="select_all"]', table.table().container()).on('click', function(e){
        if(this.checked){
            $('#datatableDeviceFwRules tbody input[type="checkbox"]:not(:checked)').trigger('click');
        } else {
            $('#datatableDeviceFwRules tbody input[type="checkbox"]:checked').trigger('click');
        }

        // Prevent click event from propagating to parent
        e.stopPropagation();
    });



    // Handle form submission event
    $('#frm-example').on('submit', function(e){
        var form = this;

        // Iterate over all selected checkboxes
        $.each(rows_selected, function(index, rowId){
            // Create a hidden element
            $(form).append(
                $('<input>')
                    .attr('type', 'hidden')
                    .attr('name', 'id[]')
                    .val(rowId)
            );
        });
    });




    $('#datatableDeviceFwRules tbody').on('click', 'td.details-control', function (e) {

        var table = $('#datatableDeviceFwRules').DataTable();
        var tr = $(this).closest('tr');
        //console.log(tr);
        var row = table.row( tr );
        //console.log(row);

        var slider = $('#slider');
        slider.html(formatDeviceDetail(row.data()));
        slider.slideReveal({
            position: "right",
            width: 350,
            push: false,
            overlay: true
        });
        slider.css('height','100%');
        slider.css('overflow-y','scroll');
        slider.slideReveal("show");

        e.stopPropagation();

        /*if ( row.child.isShown() ) {
            row.child.hide();
            tr.removeClass('shown');
        }
        else {
            row.child( format(row.data()) ).show();
            tr.addClass('shown');
        }*/
    } );

};

//FW rules DataTable
function init_NetworkFwRulesDataTable(url, typeOfView = null) {

    selel = $('#time-refresh-menu li.noauto a');
    selel.addClass('selected');

    // Array holding selected row IDs
    var rows_selected = [];

    $('#datatableNetworkFwRules tfoot th').each( function (i) {

        /*if(i > 1 && i != 6 && i != 8){

            var title = $(this).text();
            $(this).html( '<input type="text" placeholder="Search '+title+'" />' );
        }*/

    } );

    var table = $('#datatableNetworkFwRules').DataTable( {
        "processing": true,
        "serverSide": true,
        "ordering": true,
        "bAutoWidth": false,
        "lengthMenu": [[10, 25, 50, -1], [10, 25, 50, "All"]],
        "order": [[ 0, "asc" ]],
        "search": {
            "regex": false
        },
        "lengthChange": false,
        "iDisplayLength": "All",
        'paging': false,
        'rowsGroup': [0,1],

        "ajax": {
            "url": url,
            type: "get",  // method  , by default get
            "dataType": "json",
            "complete": function(response) {
                //console.log('done');
            },
            "error": handleAjaxError

        },
        "columns": [
            /*{
                className:      'select-checkbox',
                orderable:      false,
                data:           null,
                defaultContent: ''
            },*/
            { "data": "name",
                'render': function(data, type, row){
                    if(rights.networkEdit){
                        return '<b>'+data+'</b><p><a class="btn btn-info" style="padding: 2px 5px; margin-top:6px; margin-left: 5px;" href="'+Routing.generate('app_edit_network', {'id': row['id'] })+'">Edit</a></p>';
                    } else {
                        return '<b>'+data+'</b>';
                    }


                }
            },
            {"data": "policy"},
            { "data": 'related_policy',
                "orderable": false,
                'render': function(data){

                    if(data == '0'){
                        return '<div style="color: red;">Drop</div>';
                    }else{
                        return '<div style="color: green;">Accept</div>';
                    }

                }
            },
            { "data": 'protocol'},
            { "data": "ports" },
            { "data": "enabled" }
        ],
        select: {
            style:    'os',
            selector: 'td:first-child'
        },
        "columnDefs": [
            /*{
                'targets': 0,
                'searchable': false,
                'orderable': false,
                'width': '5%',
                'className': 'dt-body-center',
                'render': function (data, type, full, meta){
                    return '<input type="checkbox">';
                }
            },*/
            { orderable: false, targets: [1,2,3,4] },
            { searchable: false, targets: [1,2,3,4] },

            {
                "targets": 0,
                'width': '10%',
                'className': 'dt-center',
            },
            {
                "targets": 1,
                'width': '2%',
                'className': 'dt-center',
            },
            {
                "targets": 2,
                'className': 'dt-center',
                'width': '5%',
            },
            {
                "targets": 3,
                'className': 'dt-center',
                'width': '5%',
            },
            {
                "targets": 4,
                'width': '80%',
            },
            {
                'targets': 5,
                'className': 'dt-center',
                'width': '1%',
                'render': function (data, type, full, meta){
                    if(data == 0){
                        return '<i class="fa fa-stop" style="color: #bb4a1e" aria-hidden="true"></i><br> Disabled';
                    }else if(data == 1){
                        return '<i class="fa fa-play" style="color: #1ABB9C" aria-hidden="true"></i><br> Enabled';
                    }

                    return 'none';
                }
            },
        ],
        'rowCallback': function(row, data, dataIndex){
            // Get row ID
            var rowId = data['id'];

            // If row ID is in the list of selected row IDs
            if($.inArray(rowId, rows_selected) !== -1){
                $(row).find('input[type="checkbox"]').prop('checked', true);
                $(row).addClass('selected');
            }
        },
        initComplete: function() {
        }

    } );

};

/*
function saveEditReturn() {
    //$.cookie("previousUrl", window.location.href, {path:"/"});
    sessionStorage.setItem("editReturn", location.pathname);
};

 */
